/*
 * Copyright(C) OASIS(R) 2005,2009. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sca.annotation;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * When placed on a service interface, this annotation specifies the interface
 * to be used for callbacks.
 * <p/>
 * When placed on a method or field, this annotation denotes the injection
 * site to be used for a callback reference.
 * <p/>
 * There is a error in the 1.00 draft spec in the declaration of this interface.
 * The form defined here is a proposed correction for that error.
 *
 * @version $Rev: 833317 $ $Date: 2009-11-06 08:36:12 +0000 (Fri, 06 Nov 2009) $
 */
@Target({TYPE, METHOD, FIELD})
@Retention(RUNTIME)
public @interface Callback {
    /**
     * The Class of the associated callback interface.
     *
     * @return the associated callback interface
     */
    Class<?> value() default Void.class;
}
